@@ -1,74 +1,74 @@
 classdef AttitudeMahonyFilter < iDynTree.IAttitudeEstimator
   methods
     function self = AttitudeMahonyFilter(varargin)
-      self@iDynTree.IAttitudeEstimator(SwigRef.Null);
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      self@iDynTree.IAttitudeEstimator(iDynTreeSwigRef.Null);
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1622, varargin{:});
+        tmp = iDynTreeMEX(1624, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = useMagnetoMeterMeasurements(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1623, self, varargin{:});
-    end
-    function varargout = setConfidenceForMagnetometerMeasurements(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1624, self, varargin{:});
-    end
-    function varargout = setGainkp(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1625, self, varargin{:});
     end
-    function varargout = setGainki(self,varargin)
+    function varargout = setConfidenceForMagnetometerMeasurements(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1626, self, varargin{:});
     end
-    function varargout = setTimeStepInSeconds(self,varargin)
+    function varargout = setGainkp(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1627, self, varargin{:});
     end
-    function varargout = setGravityDirection(self,varargin)
+    function varargout = setGainki(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1628, self, varargin{:});
     end
-    function varargout = setParameters(self,varargin)
+    function varargout = setTimeStepInSeconds(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1629, self, varargin{:});
     end
-    function varargout = getParameters(self,varargin)
+    function varargout = setGravityDirection(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1630, self, varargin{:});
     end
-    function varargout = updateFilterWithMeasurements(self,varargin)
+    function varargout = setParameters(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1631, self, varargin{:});
     end
-    function varargout = propagateStates(self,varargin)
+    function varargout = getParameters(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1632, self, varargin{:});
     end
-    function varargout = getOrientationEstimateAsRotationMatrix(self,varargin)
+    function varargout = updateFilterWithMeasurements(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1633, self, varargin{:});
     end
-    function varargout = getOrientationEstimateAsQuaternion(self,varargin)
+    function varargout = propagateStates(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1634, self, varargin{:});
     end
-    function varargout = getOrientationEstimateAsRPY(self,varargin)
+    function varargout = getOrientationEstimateAsRotationMatrix(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1635, self, varargin{:});
     end
-    function varargout = getInternalStateSize(self,varargin)
+    function varargout = getOrientationEstimateAsQuaternion(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1636, self, varargin{:});
     end
-    function varargout = getInternalState(self,varargin)
+    function varargout = getOrientationEstimateAsRPY(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1637, self, varargin{:});
     end
-    function varargout = getDefaultInternalInitialState(self,varargin)
+    function varargout = getInternalStateSize(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1638, self, varargin{:});
     end
-    function varargout = setInternalState(self,varargin)
+    function varargout = getInternalState(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1639, self, varargin{:});
     end
-    function varargout = setInternalStateInitialOrientation(self,varargin)
+    function varargout = getDefaultInternalInitialState(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1640, self, varargin{:});
     end
+    function varargout = setInternalState(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1641, self, varargin{:});
+    end
+    function varargout = setInternalStateInitialOrientation(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1642, self, varargin{:});
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1641, self);
+        iDynTreeMEX(1643, self);
         self.SwigClear();
       end
     end
