@@ -4,81 +4,81 @@ classdef AttitudeQuaternionEKF < iDynTree.IAttitudeEstimator & iDynTree.Discrete
       this = iDynTreeMEX(3, self);
     end
     function self = AttitudeQuaternionEKF(varargin)
-      self@iDynTree.IAttitudeEstimator(SwigRef.Null);
-      self@iDynTree.DiscreteExtendedKalmanFilterHelper(SwigRef.Null);
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      self@iDynTree.IAttitudeEstimator(iDynTreeSwigRef.Null);
+      self@iDynTree.DiscreteExtendedKalmanFilterHelper(iDynTreeSwigRef.Null);
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1687, varargin{:});
+        tmp = iDynTreeMEX(1689, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = getParameters(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1688, self, varargin{:});
-    end
-    function varargout = setParameters(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1689, self, varargin{:});
-    end
-    function varargout = setGravityDirection(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1690, self, varargin{:});
     end
-    function varargout = setTimeStepInSeconds(self,varargin)
+    function varargout = setParameters(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1691, self, varargin{:});
     end
-    function varargout = setBiasCorrelationTimeFactor(self,varargin)
+    function varargout = setGravityDirection(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1692, self, varargin{:});
     end
-    function varargout = useMagnetometerMeasurements(self,varargin)
+    function varargout = setTimeStepInSeconds(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1693, self, varargin{:});
     end
-    function varargout = setMeasurementNoiseVariance(self,varargin)
+    function varargout = setBiasCorrelationTimeFactor(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1694, self, varargin{:});
     end
-    function varargout = setSystemNoiseVariance(self,varargin)
+    function varargout = useMagnetometerMeasurements(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1695, self, varargin{:});
     end
-    function varargout = setInitialStateCovariance(self,varargin)
+    function varargout = setMeasurementNoiseVariance(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1696, self, varargin{:});
     end
-    function varargout = initializeFilter(self,varargin)
+    function varargout = setSystemNoiseVariance(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1697, self, varargin{:});
     end
-    function varargout = updateFilterWithMeasurements(self,varargin)
+    function varargout = setInitialStateCovariance(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1698, self, varargin{:});
     end
-    function varargout = propagateStates(self,varargin)
+    function varargout = initializeFilter(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1699, self, varargin{:});
     end
-    function varargout = getOrientationEstimateAsRotationMatrix(self,varargin)
+    function varargout = updateFilterWithMeasurements(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1700, self, varargin{:});
     end
-    function varargout = getOrientationEstimateAsQuaternion(self,varargin)
+    function varargout = propagateStates(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1701, self, varargin{:});
     end
-    function varargout = getOrientationEstimateAsRPY(self,varargin)
+    function varargout = getOrientationEstimateAsRotationMatrix(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1702, self, varargin{:});
     end
-    function varargout = getInternalStateSize(self,varargin)
+    function varargout = getOrientationEstimateAsQuaternion(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1703, self, varargin{:});
     end
-    function varargout = getInternalState(self,varargin)
+    function varargout = getOrientationEstimateAsRPY(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1704, self, varargin{:});
     end
-    function varargout = getDefaultInternalInitialState(self,varargin)
+    function varargout = getInternalStateSize(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1705, self, varargin{:});
     end
-    function varargout = setInternalState(self,varargin)
+    function varargout = getInternalState(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1706, self, varargin{:});
     end
-    function varargout = setInternalStateInitialOrientation(self,varargin)
+    function varargout = getDefaultInternalInitialState(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1707, self, varargin{:});
     end
+    function varargout = setInternalState(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1708, self, varargin{:});
+    end
+    function varargout = setInternalStateInitialOrientation(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1709, self, varargin{:});
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1708, self);
+        iDynTreeMEX(1710, self);
         self.SwigClear();
       end
     end
