@@ -1,19 +1,9 @@
-classdef BerdySensor < SwigRef
+classdef BerdySensor < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function varargout = type(self, varargin)
-      narginchk(1, 2)
-      if nargin==1
-        nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1523, self);
-      else
-        nargoutchk(0, 0)
-        iDynTreeMEX(1524, self, varargin{1});
-      end
-    end
-    function varargout = id(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
@@ -23,7 +13,7 @@ classdef BerdySensor < SwigRef
         iDynTreeMEX(1526, self, varargin{1});
       end
     end
-    function varargout = range(self, varargin)
+    function varargout = id(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
@@ -33,26 +23,36 @@ classdef BerdySensor < SwigRef
         iDynTreeMEX(1528, self, varargin{1});
       end
     end
+    function varargout = range(self, varargin)
+      narginchk(1, 2)
+      if nargin==1
+        nargoutchk(0, 1)
+        varargout{1} = iDynTreeMEX(1529, self);
+      else
+        nargoutchk(0, 0)
+        iDynTreeMEX(1530, self, varargin{1});
+      end
+    end
     function varargout = eq(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1529, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1531, self, varargin{:});
     end
     function varargout = lt(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1530, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1532, self, varargin{:});
     end
     function self = BerdySensor(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1531, varargin{:});
+        tmp = iDynTreeMEX(1533, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1532, self);
+        iDynTreeMEX(1534, self);
         self.SwigClear();
       end
     end
