@@ -1,34 +1,34 @@
-classdef FreeFloatingGeneralizedTorques < SwigRef
+classdef FreeFloatingGeneralizedTorques < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function self = FreeFloatingGeneralizedTorques(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1121, varargin{:});
+        tmp = iDynTreeMEX(1123, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = resize(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1122, self, varargin{:});
-    end
-    function varargout = baseWrench(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1123, self, varargin{:});
-    end
-    function varargout = jointTorques(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1124, self, varargin{:});
     end
-    function varargout = getNrOfDOFs(self,varargin)
+    function varargout = baseWrench(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1125, self, varargin{:});
     end
+    function varargout = jointTorques(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1126, self, varargin{:});
+    end
+    function varargout = getNrOfDOFs(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1127, self, varargin{:});
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1126, self);
+        iDynTreeMEX(1128, self);
         self.SwigClear();
       end
     end
