@@ -1,37 +1,37 @@
-classdef IJetsVisualization < SwigRef
+classdef IJetsVisualization < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1848, self);
+        iDynTreeMEX(1851, self);
         self.SwigClear();
       end
     end
     function varargout = setJetsFrames(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1849, self, varargin{:});
-    end
-    function varargout = getNrOfJets(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1850, self, varargin{:});
-    end
-    function varargout = getJetDirection(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1851, self, varargin{:});
-    end
-    function varargout = setJetDirection(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1852, self, varargin{:});
     end
-    function varargout = setJetColor(self,varargin)
+    function varargout = getNrOfJets(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1853, self, varargin{:});
     end
-    function varargout = setJetsDimensions(self,varargin)
+    function varargout = getJetDirection(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1854, self, varargin{:});
     end
-    function varargout = setJetsIntensity(self,varargin)
+    function varargout = setJetDirection(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1855, self, varargin{:});
     end
+    function varargout = setJetColor(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1856, self, varargin{:});
+    end
+    function varargout = setJetsDimensions(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1857, self, varargin{:});
+    end
+    function varargout = setJetsIntensity(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1858, self, varargin{:});
+    end
     function self = IJetsVisualization(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
