@@ -1,43 +1,43 @@
-classdef LinkContactWrenches < SwigRef
+classdef LinkContactWrenches < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function self = LinkContactWrenches(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1144, varargin{:});
+        tmp = iDynTreeMEX(1146, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = resize(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1145, self, varargin{:});
-    end
-    function varargout = getNrOfContactsForLink(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1146, self, varargin{:});
-    end
-    function varargout = setNrOfContactsForLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1147, self, varargin{:});
     end
-    function varargout = getNrOfLinks(self,varargin)
+    function varargout = getNrOfContactsForLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1148, self, varargin{:});
     end
-    function varargout = contactWrench(self,varargin)
+    function varargout = setNrOfContactsForLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1149, self, varargin{:});
     end
-    function varargout = computeNetWrenches(self,varargin)
+    function varargout = getNrOfLinks(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1150, self, varargin{:});
     end
-    function varargout = toString(self,varargin)
+    function varargout = contactWrench(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1151, self, varargin{:});
     end
+    function varargout = computeNetWrenches(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1152, self, varargin{:});
+    end
+    function varargout = toString(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1153, self, varargin{:});
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1152, self);
+        iDynTreeMEX(1154, self);
         self.SwigClear();
       end
     end
