@@ -1,43 +1,43 @@
-classdef Material < SwigRef
+classdef Material < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function self = Material(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(977, varargin{:});
+        tmp = iDynTreeMEX(979, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = name(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(978, self, varargin{:});
-    end
-    function varargout = hasColor(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(979, self, varargin{:});
-    end
-    function varargout = color(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(980, self, varargin{:});
     end
-    function varargout = setColor(self,varargin)
+    function varargout = hasColor(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(981, self, varargin{:});
     end
-    function varargout = hasTexture(self,varargin)
+    function varargout = color(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(982, self, varargin{:});
     end
-    function varargout = texture(self,varargin)
+    function varargout = setColor(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(983, self, varargin{:});
     end
-    function varargout = setTexture(self,varargin)
+    function varargout = hasTexture(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(984, self, varargin{:});
     end
+    function varargout = texture(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(985, self, varargin{:});
+    end
+    function varargout = setTexture(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(986, self, varargin{:});
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(985, self);
+        iDynTreeMEX(987, self);
         self.SwigClear();
       end
     end
