@@ -1,26 +1,26 @@
 classdef MomentumFreeFloatingJacobian < iDynTree.MatrixDynSize
   methods
     function self = MomentumFreeFloatingJacobian(varargin)
-      self@iDynTree.MatrixDynSize(SwigRef.Null);
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      self@iDynTree.MatrixDynSize(iDynTreeSwigRef.Null);
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1108, varargin{:});
+        tmp = iDynTreeMEX(1110, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = resize(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1109, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1111, self, varargin{:});
     end
     function varargout = isConsistent(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1110, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1112, self, varargin{:});
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1111, self);
+        iDynTreeMEX(1113, self);
         self.SwigClear();
       end
     end
