@@ -1,92 +1,92 @@
 classdef RevoluteJoint < iDynTree.MovableJointImpl1
   methods
     function self = RevoluteJoint(varargin)
-      self@iDynTree.MovableJointImpl1(SwigRef.Null);
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      self@iDynTree.MovableJointImpl1(iDynTreeSwigRef.Null);
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(910, varargin{:});
+        tmp = iDynTreeMEX(912, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(911, self);
+        iDynTreeMEX(913, self);
         self.SwigClear();
       end
     end
     function varargout = clone(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(912, self, varargin{:});
-    end
-    function varargout = setAttachedLinks(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(913, self, varargin{:});
-    end
-    function varargout = setRestTransform(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(914, self, varargin{:});
     end
-    function varargout = setAxis(self,varargin)
+    function varargout = setAttachedLinks(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(915, self, varargin{:});
     end
-    function varargout = getFirstAttachedLink(self,varargin)
+    function varargout = setRestTransform(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(916, self, varargin{:});
     end
-    function varargout = getSecondAttachedLink(self,varargin)
+    function varargout = setAxis(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(917, self, varargin{:});
     end
-    function varargout = getAxis(self,varargin)
+    function varargout = getFirstAttachedLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(918, self, varargin{:});
     end
-    function varargout = getRestTransform(self,varargin)
+    function varargout = getSecondAttachedLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(919, self, varargin{:});
     end
-    function varargout = getTransform(self,varargin)
+    function varargout = getAxis(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(920, self, varargin{:});
     end
-    function varargout = getTransformDerivative(self,varargin)
+    function varargout = getRestTransform(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(921, self, varargin{:});
     end
-    function varargout = getMotionSubspaceVector(self,varargin)
+    function varargout = getTransform(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(922, self, varargin{:});
     end
-    function varargout = computeChildPosVelAcc(self,varargin)
+    function varargout = getTransformDerivative(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(923, self, varargin{:});
     end
-    function varargout = computeChildVel(self,varargin)
+    function varargout = getMotionSubspaceVector(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(924, self, varargin{:});
     end
-    function varargout = computeChildVelAcc(self,varargin)
+    function varargout = computeChildPosVelAcc(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(925, self, varargin{:});
     end
-    function varargout = computeChildAcc(self,varargin)
+    function varargout = computeChildVel(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(926, self, varargin{:});
     end
-    function varargout = computeChildBiasAcc(self,varargin)
+    function varargout = computeChildVelAcc(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(927, self, varargin{:});
     end
-    function varargout = computeJointTorque(self,varargin)
+    function varargout = computeChildAcc(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(928, self, varargin{:});
     end
-    function varargout = hasPosLimits(self,varargin)
+    function varargout = computeChildBiasAcc(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(929, self, varargin{:});
     end
-    function varargout = enablePosLimits(self,varargin)
+    function varargout = computeJointTorque(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(930, self, varargin{:});
     end
-    function varargout = getPosLimits(self,varargin)
+    function varargout = hasPosLimits(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(931, self, varargin{:});
     end
-    function varargout = getMinPosLimit(self,varargin)
+    function varargout = enablePosLimits(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(932, self, varargin{:});
     end
-    function varargout = getMaxPosLimit(self,varargin)
+    function varargout = getPosLimits(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(933, self, varargin{:});
     end
-    function varargout = setPosLimits(self,varargin)
+    function varargout = getMinPosLimit(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(934, self, varargin{:});
     end
+    function varargout = getMaxPosLimit(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(935, self, varargin{:});
+    end
+    function varargout = setPosLimits(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(936, self, varargin{:});
+    end
   end
   methods(Static)
   end
