@@ -1,71 +1,71 @@
 classdef ThreeAxisForceTorqueContactSensor < iDynTree.LinkSensor
   methods
     function self = ThreeAxisForceTorqueContactSensor(varargin)
-      self@iDynTree.LinkSensor(SwigRef.Null);
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      self@iDynTree.LinkSensor(iDynTreeSwigRef.Null);
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1363, varargin{:});
+        tmp = iDynTreeMEX(1365, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1364, self);
+        iDynTreeMEX(1366, self);
         self.SwigClear();
       end
     end
     function varargout = setName(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1365, self, varargin{:});
-    end
-    function varargout = setLinkSensorTransform(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1366, self, varargin{:});
-    end
-    function varargout = setParentLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1367, self, varargin{:});
     end
-    function varargout = setParentLinkIndex(self,varargin)
+    function varargout = setLinkSensorTransform(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1368, self, varargin{:});
     end
-    function varargout = getName(self,varargin)
+    function varargout = setParentLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1369, self, varargin{:});
     end
-    function varargout = getSensorType(self,varargin)
+    function varargout = setParentLinkIndex(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1370, self, varargin{:});
     end
-    function varargout = getParentLink(self,varargin)
+    function varargout = getName(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1371, self, varargin{:});
     end
-    function varargout = getParentLinkIndex(self,varargin)
+    function varargout = getSensorType(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1372, self, varargin{:});
     end
-    function varargout = getLinkSensorTransform(self,varargin)
+    function varargout = getParentLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1373, self, varargin{:});
     end
-    function varargout = isValid(self,varargin)
+    function varargout = getParentLinkIndex(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1374, self, varargin{:});
     end
-    function varargout = clone(self,varargin)
+    function varargout = getLinkSensorTransform(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1375, self, varargin{:});
     end
-    function varargout = updateIndices(self,varargin)
+    function varargout = isValid(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1376, self, varargin{:});
     end
-    function varargout = setLoadCellLocations(self,varargin)
+    function varargout = clone(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1377, self, varargin{:});
     end
-    function varargout = getLoadCellLocations(self,varargin)
+    function varargout = updateIndices(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1378, self, varargin{:});
     end
-    function varargout = computeThreeAxisForceTorqueFromLoadCellMeasurements(self,varargin)
+    function varargout = setLoadCellLocations(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1379, self, varargin{:});
     end
-    function varargout = computeCenterOfPressureFromLoadCellMeasurements(self,varargin)
+    function varargout = getLoadCellLocations(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1380, self, varargin{:});
     end
+    function varargout = computeThreeAxisForceTorqueFromLoadCellMeasurements(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1381, self, varargin{:});
+    end
+    function varargout = computeCenterOfPressureFromLoadCellMeasurements(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1382, self, varargin{:});
+    end
   end
   methods(Static)
   end
