@@ -1,42 +1,32 @@
-classdef estimateExternalWrenchesBuffers < SwigRef
+classdef estimateExternalWrenchesBuffers < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function self = estimateExternalWrenchesBuffers(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1453, varargin{:});
+        tmp = iDynTreeMEX(1455, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = resize(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1454, self, varargin{:});
-    end
-    function varargout = getNrOfSubModels(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1455, self, varargin{:});
-    end
-    function varargout = getNrOfLinks(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1456, self, varargin{:});
     end
-    function varargout = isConsistent(self,varargin)
+    function varargout = getNrOfSubModels(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1457, self, varargin{:});
     end
-    function varargout = A(self, varargin)
-      narginchk(1, 2)
-      if nargin==1
-        nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1458, self);
-      else
-        nargoutchk(0, 0)
-        iDynTreeMEX(1459, self, varargin{1});
-      end
+    function varargout = getNrOfLinks(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1458, self, varargin{:});
     end
-    function varargout = x(self, varargin)
+    function varargout = isConsistent(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1459, self, varargin{:});
+    end
+    function varargout = A(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
@@ -46,7 +36,7 @@ classdef estimateExternalWrenchesBuffers < SwigRef
         iDynTreeMEX(1461, self, varargin{1});
       end
     end
-    function varargout = b(self, varargin)
+    function varargout = x(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
@@ -56,7 +46,7 @@ classdef estimateExternalWrenchesBuffers < SwigRef
         iDynTreeMEX(1463, self, varargin{1});
       end
     end
-    function varargout = pinvA(self, varargin)
+    function varargout = b(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
@@ -66,7 +56,7 @@ classdef estimateExternalWrenchesBuffers < SwigRef
         iDynTreeMEX(1465, self, varargin{1});
       end
     end
-    function varargout = b_contacts_subtree(self, varargin)
+    function varargout = pinvA(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
@@ -76,7 +66,7 @@ classdef estimateExternalWrenchesBuffers < SwigRef
         iDynTreeMEX(1467, self, varargin{1});
       end
     end
-    function varargout = subModelBase_H_link(self, varargin)
+    function varargout = b_contacts_subtree(self, varargin)
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
@@ -86,9 +76,19 @@ classdef estimateExternalWrenchesBuffers < SwigRef
         iDynTreeMEX(1469, self, varargin{1});
       end
     end
+    function varargout = subModelBase_H_link(self, varargin)
+      narginchk(1, 2)
+      if nargin==1
+        nargoutchk(0, 1)
+        varargout{1} = iDynTreeMEX(1470, self);
+      else
+        nargoutchk(0, 0)
+        iDynTreeMEX(1471, self, varargin{1});
+      end
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1470, self);
+        iDynTreeMEX(1472, self);
         self.SwigClear();
       end
     end
